searchData={"items":[{"type":"module","title":"Adbc","doc":"Bindings for Arrow Database Connectivity (ADBC).\n\nAdbc provides a standard database interface using the\nApache Arrow format.","ref":"Adbc.html"},{"type":"module","title":"Installation - Adbc","doc":"First, add `:adbc` as a dependency in your `mix.exs`:\n\n    {:adbc, \"~> 0.1\"}\n\nNow, in your config/config.exs, configure the drivers you\nare going to use:\n\n    config :adbc, :drivers, [:sqlite]\n\nIf you are using a notebook or scripting, you can also use\n`Adbc.download_driver!/1` to dynamically download one.\n\nThen start the database and the relevant connection processes\nin your supervision tree:\n\n    children = [\n      {Adbc.Database,\n       driver: :sqlite,\n       process_options: [name: MyApp.DB]},\n      {Adbc.Connection,\n       database: MyApp.DB,\n       process_options: [name: MyApp.Conn]}\n    ]\n\n    Supervisor.start_link(children, strategy: :one_for_one)\n\nIn a notebook, the above would look like this:\n\n    db = Kino.start_child!({Adbc.Database, driver: :sqlite})\n    conn = Kino.start_child!({Adbc.Connection, database: db})\n\nAnd now you can make queries with:\n\n    # For named connections\n    {:ok, _} = Adbc.Connection.query(MyApp.Conn, \"SELECT 123\")\n\n    # When using the conn PID directly\n    {:ok, _} = Adbc.Connection.query(conn, \"SELECT 123\")","ref":"Adbc.html#module-installation"},{"type":"module","title":"Supported drivers - Adbc","doc":"Below we list all drivers supported out of the box. You may also\ngive the full path to a driver in the `:driver` option to load other\nexisting drivers.\n\n#","ref":"Adbc.html#module-supported-drivers"},{"type":"module","title":"DuckDB - Adbc","doc":"The DuckDB driver provides access to in-memory DuckDB databases.\n\n##","ref":"Adbc.html#module-duckdb"},{"type":"module","title":"Examples - Adbc","doc":"{Adbc.Database, driver: :duckdb}\n\n#","ref":"Adbc.html#module-examples"},{"type":"module","title":"PostgreSQL - Adbc","doc":"The PostgreSQL driver provides access to any database that supports\nthe PostgreSQL wire format. It is implemented as a wrapper around\n`libpq`.\n\n##","ref":"Adbc.html#module-postgresql"},{"type":"module","title":"Examples - Adbc","doc":"{Adbc.Database, driver: :postgresql, uri: \"postgresql://postgres@localhost\"}\n\nYou must pass the `:uri` option using Postgres'\n[connection URI](https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING):\n\n#","ref":"Adbc.html#module-examples"},{"type":"module","title":"Sqlite - Adbc","doc":"The SQLite driver provides access to SQLite databases.\n\n##","ref":"Adbc.html#module-sqlite"},{"type":"module","title":"Examples - Adbc","doc":"{Adbc.Database, driver: :sqlite, uri: \":memory:\"}\n    {Adbc.Database, driver: :sqlite, uri: \"./db/my.db\"}\n    {Adbc.Database, driver: :sqlite, uri: \"file:/path/to/file/in/disk.db\"}\n\nThe `:uri` option should be, \":memory:\", a filename or\n[URI filename](https://www.sqlite.org/c3ref/open.html#urifilenamesinsqlite3open).\nIf omitted, it will default to an in-memory database, but\none that is shared across all connections.\n\n#","ref":"Adbc.html#module-examples"},{"type":"module","title":"Snowflake - Adbc","doc":"The Snowflake driver provides access to Snowflake Database Warehouses.\n\n##","ref":"Adbc.html#module-snowflake"},{"type":"module","title":"Examples - Adbc","doc":"{Adbc.Database, driver: :snowflake, uri: \"...\"}\n\nThe Snowflake URI should be of one of the following formats:\n\n    user[:password]@account/database/schema[?param1=value1&paramN=valueN]\n    user[:password]@account/database[?param1=value1&paramN=valueN]\n    user[:password]@host:port/database/schema?account=user_account[&param1=value1&paramN=valueN]\n    host:port/database/schema?account=user_account[&param1=value1&paramN=valueN]\n\nThe first two are the most recommended formats. The schema, database and parameters are optional.\nSee [Account identifiers](https://docs.snowflake.com/en/user-guide/admin-account-identifier) for more information.","ref":"Adbc.html#module-examples"},{"type":"function","title":"Adbc.download_driver/2","doc":"Downloads a driver.\n\nSee `Adbc` module doc for all supports drivers.\nIt returns `:ok` or `{:error, binary}`.","ref":"Adbc.html#download_driver/2"},{"type":"function","title":"Adbc.download_driver!/2","doc":"Downloads a driver and raises in case of errors.\n\nSee `Adbc` module doc for all supports drivers.\nIt returns `:ok`.","ref":"Adbc.html#download_driver!/2"},{"type":"module","title":"Adbc.Connection","doc":"Documentation for `Adbc.Connection`.\n\nConnection are modelled as processes. They require\nan `Adbc.Database` to be started.","ref":"Adbc.Connection.html"},{"type":"function","title":"Adbc.Connection.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Adbc.Connection.html#child_spec/1"},{"type":"function","title":"Adbc.Connection.get_driver/1","doc":"Gets the underlying driver of a connection process.","ref":"Adbc.Connection.html#get_driver/1"},{"type":"function","title":"Examples - Adbc.Connection.get_driver/1","doc":"ADBC.Connection.get_driver(conn)\n    #=> {:ok, :sqlite}","ref":"Adbc.Connection.html#get_driver/1-examples"},{"type":"function","title":"Adbc.Connection.get_info/2","doc":"Get metadata about the database/driver.\n\nThe result is an Arrow dataset with the following schema:\n\n\n| Field Name                 |  Field Type    | Null Contstraint  |\n| -------------------------- | ---------------|------------------ |\n| `info_name`                |  `uint32`      | not null          |\n| `info_value`               |  `INFO_SCHEMA` |                   |\n\n`INFO_SCHEMA` is a dense union with members:\n\n| Field Name       | Type Code |  Field Type                   |\n| -----------------| --------- | ----------------------------- |\n| `string_value`              | 0 |  `utf8`                    |\n| `bool_value`                | 1 |  `bool`                    |\n| `int64_value`               | 2 |  `int64`                   |\n| `int32_bitmask`             | 3 |  `int32`                   |\n| `string_list`               | 4 |  `list `              |\n| `int32_to_int32_list_map`   | 5 |  `map >` |\n\nEach metadatum is identified by an integer code. The recognized\ncodes are defined as constants. Codes [0, 10_000) are reserved\nfor ADBC usage. Drivers/vendors will ignore requests for\nunrecognized codes (the row will be omitted from the result).","ref":"Adbc.Connection.html#get_info/2"},{"type":"function","title":"Adbc.Connection.get_objects/3","doc":"Get a hierarchical view of all catalogs, database schemas, tables, and columns.\n\nThe result is an Arrow dataset with the following schema:\n\n| Field Name               | Field Type                |\n|--------------------------|---------------------------|\n| `catalog_name`           | `utf8`                    |\n| `catalog_db_schemas`     | `list `  |\n\n`DB_SCHEMA_SCHEMA` is a Struct with fields:\n\n| Field Name             | Field Type              |\n|------------------------|-------------------------|\n| `db_schema_name`       | `utf8`                  |\n| `db_schema_tables`     | `list `    |\n\n`TABLE_SCHEMA` is a Struct with fields:\n\n| Field Name           | Field Type                | Null Contstraint   |\n|----------------------|---------------------------|--------------------|\n| `table_name`         | `utf8`                    | not null           |\n| `table_type`         | `utf8`                    | not null           |\n| `table_columns`      | `list `     |                    |\n| `table_constraints`  | `list ` |                    |\n\n`COLUMN_SCHEMA` is a Struct with fields:\n\n| Field Name               | Field Type  | Null Contstraint | Comments |\n|--------------------------|-------------|-----------       |----------|\n| `column_name`              | `utf8`    | not null         |          |\n| `ordinal_position`         | `int32`   |                  | (1)      |\n| `remarks`                  | `utf8`    |                  | (2)      |\n| `xdbc_data_type`           | `int16`   |                  | (3)      |\n| `xdbc_type_name`           | `utf8`    |                  | (3)      |\n| `xdbc_column_size`         | `int32`   |                  | (3)      |\n| `xdbc_decimal_digits`      | `int16`   |                  | (3)      |\n| `xdbc_num_prec_radix`      | `int16`   |                  | (3)      |\n| `xdbc_nullable`            | `int16`   |                  | (3)      |\n| `xdbc_column_def`          | `utf8`    |                  | (3)      |\n| `xdbc_sql_data_type`       | `int16`   |                  | (3)      |\n| `xdbc_datetime_sub`        | `int16`   |                  | (3)      |\n| `xdbc_char_octet_length`   | `int32`   |                  | (3)      |\n| `xdbc_is_nullable`         | `utf8`    |                  | (3)      |\n| `xdbc_scope_catalog`       | `utf8`    |                  | (3)      |\n| `xdbc_scope_schema`        | `utf8`    |                  | (3)      |\n| `xdbc_scope_table`         | `utf8`    |                  | (3)      |\n| `xdbc_is_autoincrement`    | `bool`    |                  | (3)      |\n| `xdbc_is_generatedcolumn`  | `bool`    |                  | (3)      |\n\n1. The column's ordinal position in the table (starting from 1).\n2. Database-specific description of the column.\n3. Optional value. Should be null if not supported by the driver.\n   `xdbc_` values are meant to provide JDBC/ODBC-compatible metadata\n   in an agnostic manner.\n\n`CONSTRAINT_SCHEMA` is a Struct with fields:\n\n| Field Name                | Field Type         | Null Contstraint | Comments |\n|---------------------------|--------------------|------------------|----------|\n| `constraint_name`         | `utf8`               |                  |          |\n| `constraint_type`         | `utf8`               | not null         | (1)      |\n| `constraint_column_names` | `list `         | not null         | (2)      |\n| `constraint_column_usage` | `list ` |                  | (3)      |\n\n1. One of 'CHECK', 'FOREIGN KEY', 'PRIMARY KEY', or 'UNIQUE'.\n2. The columns on the current table that are constrained, in order.\n3. For FOREIGN KEY only, the referenced table and columns.\n\n`USAGE_SCHEMA` is a Struct with fields:\n\n| Field Name               | Field Type  | Null Contstraint |\n|--------------------------|-------------|------------------|\n| `fk_catalog`             | `utf8`        |                  |\n| `fk_db_schema`           | `utf8`        |                  |\n| `fk_table`               | `utf8`        | not null         |\n| `fk_column_name`         | `utf8`        | not null         |","ref":"Adbc.Connection.html#get_objects/3"},{"type":"function","title":"Adbc.Connection.get_table_types/1","doc":"Get a list of table types in the database.\n\nThe result is an Arrow dataset with the following schema:\n\n| Field Name     | Field Type    | Null Contstraint |\n|----------------|---------------|------------------|\n| `table_type`   | `utf8`        | not null         |","ref":"Adbc.Connection.html#get_table_types/1"},{"type":"function","title":"Adbc.Connection.prepare/2","doc":"Prepares the given `query`.","ref":"Adbc.Connection.html#prepare/2"},{"type":"function","title":"Adbc.Connection.query/3","doc":"Runs the given `query` with `params`.","ref":"Adbc.Connection.html#query/3"},{"type":"function","title":"Adbc.Connection.query!/3","doc":"Same as `query/3` but raises an exception on error.","ref":"Adbc.Connection.html#query!/3"},{"type":"function","title":"Adbc.Connection.query_pointer/4","doc":"Runs the given `query` with `params` and\npass the ArrowStream pointer to the given function.\n\nThe pointer will point to a valid ArrowStream through\nthe duration of the function. The function may call\nnative code that consumes the ArrowStream accordingly.","ref":"Adbc.Connection.html#query_pointer/4"},{"type":"function","title":"Adbc.Connection.start_link/1","doc":"Starts a connection process.","ref":"Adbc.Connection.html#start_link/1"},{"type":"function","title":"Options - Adbc.Connection.start_link/1","doc":"* `:database` (required) - the database process to connect to\n\n  * `:process_options` - the options to be given to the underlying\n    process. See `GenServer.start_link/3` for all options","ref":"Adbc.Connection.html#start_link/1-options"},{"type":"function","title":"Examples - Adbc.Connection.start_link/1","doc":"Adbc.Connection.start_link(\n      database: MyApp.DB,\n      process_options: [name: MyApp.Conn]\n    )\n\nIn your supervision tree it would be started like this:\n\n    children = [\n      {Adbc.Connection,\n       database: MyApp.DB,\n       process_options: [name: MyApp.Conn]}\n    ]","ref":"Adbc.Connection.html#start_link/1-examples"},{"type":"type","title":"Adbc.Connection.result_set/0","doc":"","ref":"Adbc.Connection.html#t:result_set/0"},{"type":"type","title":"Adbc.Connection.t/0","doc":"","ref":"Adbc.Connection.html#t:t/0"},{"type":"module","title":"Adbc.Database","doc":"Documentation for `Adbc.Database`.\n\nDatabases are modelled as processes. They required\na driver to be started.","ref":"Adbc.Database.html"},{"type":"function","title":"Adbc.Database.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Adbc.Database.html#child_spec/1"},{"type":"function","title":"Adbc.Database.start_link/1","doc":"Starts a database process.","ref":"Adbc.Database.html#start_link/1"},{"type":"function","title":"Options - Adbc.Database.start_link/1","doc":"* `:driver` (required) - the driver to use for this database.\n    It must be an atom (see `Adbc` module documentation for all\n    built-in drivers) or a string representing the path to a driver\n\n  * `:process_options` - the options to be given to the underlying\n    process. See `GenServer.start_link/3` for all options\n\nAll other options are given as database options to the underlying driver.","ref":"Adbc.Database.html#start_link/1-options"},{"type":"function","title":"Examples - Adbc.Database.start_link/1","doc":"Adbc.Database.start_link(\n      driver: :sqlite,\n      process_options: [name: MyApp.DB]\n    )\n\nIn your supervision tree it would be started like this:\n\n    children = [\n      {Adbc.Database,\n       driver: :sqlite,\n       process_options: [name: MyApp.DB]},\n    ]","ref":"Adbc.Database.html#start_link/1-examples"},{"type":"module","title":"Adbc.Result","doc":"A struct returned as result from queries.\n\nIt has two fields:\n\n  * `:data` - a map of field names to a list of values\n\n  * `:num_rows` - the number of rows returned, if returned\n    by the database","ref":"Adbc.Result.html"},{"type":"type","title":"Adbc.Result.t/0","doc":"","ref":"Adbc.Result.html#t:t/0"},{"type":"exception","title":"Adbc.Error","doc":"","ref":"Adbc.Error.html"},{"type":"type","title":"Adbc.Error.t/0","doc":"","ref":"Adbc.Error.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}